neochain
========
Network Evolution Observation for Blockchain

.. image:: https://badge.fury.io/py/neochain.svg
    :alt: pypi version
    :target: https://badge.fury.io/py/neochain

.. image:: https://img.shields.io/packagist/l/doctrine/orm.svg
    :alt: license
    :target: https://opensource.org/licenses/MIT

.. image:: https://travis-ci.org/dharif23/neochain.svg?branch=master
    :alt: Build Status
    :target: https://travis-ci.org/dharif23/neochain

.. image:: https://readthedocs.org/projects/neochain/badge/?version=latest
    :alt: Documentation Status
    :target: https://neochain.readthedocs.io/?badge=latest

Description
===========

`NEOChain <https://www.neochain.readthedocs.io>`_ (neochain) is a Network Evolution Observation library for Blockchain networks.
This specially designed python library can provide tools to detect community structures in massive networks like **Blockchain**
and also capable of merging one or more timed snapshot of transaction data into one large snapshot without losing any nodes to
better understand the evolution of the network.

Getting Started
===============
.. code-block:: python

   python setup.py install


Documentation
=============
For more details please see: `NEOChain Documentation <http://neochain.readthedocs.io/>`_

